@@ -1,4 +1,4 @@
-require File.join(File.dirname(__FILE__), 'preamble')
+require "preamble"
 require "text/double_metaphone"
 
 require 'csv'
@@ -6,7 +6,7 @@ require 'csv'
 class DoubleMetaphoneTest < Test::Unit::TestCase
 
   def test_cases
-    CSV.open(File.rel('data', 'double_metaphone.csv'), 'r').to_a.each do |row|
+    CSV.open(data_file_path('double_metaphone.csv'), 'r').to_a.each do |row|
       primary, secondary = Text::Metaphone.double_metaphone(row[0])
 
       assert_equal row[1], primary
